*============================================================================
*	List of parameters subject to sensitivity analysis
*	The user can change the default settings.

*	Choice of key elasticities:

*	Elasticity of substitution in final consumption
$if not setglobal esub_c $setglobal esub_c 0.75

*	Elasticity in coal supply
$if not setglobal esub_coal  $setglobal esub_coal 0.5   

*	Elasticity in gas supply
$if not setglobal esub_gas  $setglobal esub_gas  0.25 

*	Elasticity in oil supply
$if not setglobal esub_oil  $setglobal esub_oil 0.25   


*	Choice of time horizon (short, long) for static model version
*	N.B.: For short-run analysis capital is immobile across sectors
$if not setglobal horizon  $setglobal horizon long  


*	Choice of resource availability for renewables 
*	as a fraction of base-year total electricity production
*	(except for hydro which is assumed to operate at upper
*	bound or resource availability in the base year) 

*	Potential wind supply - (%)
$if not setglobal p_wind  $setglobal p_wind  25

*	Potential biomass supply - (%)
$if not setglobal p_biomass  $setglobal p_biomass 50

*	Potential solar supply - (%)
$if not setglobal p_solar  $setglobal p_solar  50

*	Cost disadvantage of inital slack technologies:
*	Wind energy premium (%)
$if not setglobal c_wind  $setglobal c_wind 10 

*	Biomass energy premium (%)
$if not setglobal c_biomass  $setglobal c_biomass 30 

*	Solar energy premium (%)
$if not setglobal c_solar  $setglobal c_solar 100


*============================================================================
*	Assign user-specific changes of default assumptions

scalar	shortrun	Flag for short-run capital mobility/1/;

$if "%horizon%"=="long" shortrun=0;

*	Elasticitities of substitution (ESUB)	
scalar	esub_kl     ESUB between capital and labor in Y production /1/
	esub_nele   ESUB between fossil fuel inputs in Y production /2/
	esub_ele    ESUB between electricity and fossil fuel composite in Y production /1/	
	esub	    ESUB between VA and energy composite in Y production/0.5/
	esubc	    ESUB between non-energy and energy composite in final demand /%esub_c%/
	esubc_nele  ESUB between fossil fuel inputs in consumption /1/
	esubc_ele   ESUB between electricity and fossil fuel composite in consumption /0.3/;	


set	kg	Specific capital stocks in non-fossil fuel production (dynamic version) 
		/y,coal,gas,oil,nuclear,hydro,wind,solar,biomass/;
	
set	t(kg)	Electricity technologies (current and future)
		/coal,gas,oil,nuclear,hydro,wind,solar,biomass/;

set	xt(t)	Existing technologies /coal,oil,gas,nuclear,hydro/;

set	nt(t)	New vintage technologies /wind,solar,biomass/;

set	ff	Fossil fuel inputs /coa, gas, oil/;

set	n	Natural resources /wind, sun, trees, water/;

set	res(t)  Renewable energy sources /hydro, wind, solar, biomass/;	

alias(f,ff);

*	World economic flow data as of GTAP6 in 2001 (billion US dollars)
table sam(*,*)  Base year social accounting matrix
                 Y         coa         gas         oil         ele          ra
Y            30864         -36         -71        -216        -267      -30274
coa            -12         105                     -15         -78	       
gas            -83                     249         -33         -86         -47
oil           -721                      -2        1151         -61        -367
ele           -746          -6          -4         -23        1126        -347
labor       -17088         -20         -35        -141        -180       17464
capital     -12214         -17         -99        -434        -454       13218
rent                       -26         -38        -289                     353;


set	rlabel	Row labels of SAM / Y, coa, gas, oil, ele, labor, capital, rent/,
	clabel  Column labels of SAM /Y, coa, gas, oil, ele, ra/;

*	Scale down input data to ease the numerical soluton process
scalar	multi	Scaling factor of monetary SAM /0.001/;

sam(rlabel,clabel) = multi*sam(rlabel,clabel);   


parameter  esub_ff(ff)	Elastictity of substitution in fossil fuel production 
	/gas %esub_gas%, coa %esub_coal%, oil %esub_oil%/;

*	Use world electricity generation (TWh) in 2002 (World Energy Outlook 2004)
*	in order to share electricty production across technologies (N.B.: the 
*	tiny amounts of "other renewables", "biomass" and "waste" are accounted
*	for within "hydro")

parameter	elecgen	/coal		6241
			 oil		1181
			 gas		3070	
			 nuclear	2654
			 hydro		2928
			/;  

elecgen("total") = sum(xt, elecgen(xt));

parameter xtelec  Electricity technologies - extant (initially active);

xtelec("ele",xt)     = sam("ele","ele")* elecgen(xt)/elecgen("total");
xtelec("gas","gas")  = sam("gas","ele");
xtelec("coa","coal") = sam("coa","ele");
xtelec("oil","oil")  = sam("oil","ele");
xtelec("other",xt)   = xtelec("ele",xt) + xtelec("coa",xt) + xtelec("gas",xt) + xtelec("oil",xt);
display xtelec;

*	Assume non-fuel inputs have common value shares:
set nfuel /y,capital,labor/;

elecgen("nonfuel") = sum(nfuel,sam(nfuel,"ele"));
xtelec(nfuel,xt)   = - xtelec("other",xt) * sam(nfuel,"ele")/elecgen("nonfuel");

xtelec("other",xt) = 0;

set inputs /Y, coa, gas, oil, ele, capital, labor/;  
xtelec("profit",xt) = sum(inputs, xtelec(inputs,xt));
display xtelec;


table ntelec  Electricity technologies - new vintage (initially inactive)

	 wind	 solar	 biomass
ele	  1.0	   1.0	    1.0
Y         -.1	   -.1      -.5
capital   -.9	  -1.8	    -.5
labor     -.1      -.1      -.3
wind	   -1
sun		    -1
trees			     -1;

*	Adjust the cost coefficients for initially inactive technologies 
*	according to user assumptions:
set xk /y,capital/;

ntelec(xk,"wind")    = ntelec(xk,"wind")    * (100+%c_wind%)/110;
ntelec(xk,"biomass") = ntelec(xk,"biomass") * (100+%c_biomass%)/130;
ntelec(xk,"solar")   = ntelec(xk,"solar")   * (100+%c_solar%)/200;


parameter  nrsupply(*)	Natural resource supplies (fraction of base output)/
	wind		%p_wind%
	sun		%p_solar%
	trees		%p_biomass% /;

nrsupply(res)	   = nrsupply(res)/100 * sam("ele","ele");

*	Supply of extant hydro is fixed at the base year level
nrsupply("water")       = xtelec("ele","hydro");
xtelec("water","hydro") = -1;

*	Flags for alternative scenario settings
scalar	
	dd	Flag for double dividend policy analysis /0/,
	ls	Flag for lump-sum revenue-recyling	 /0/,
	vat	Flag for VAT revenue recycling		 /0/,
	g0	Base year public consumption		 /0/,
	tc0	Base year consumption tax		 /0/,
	co2	Flag for carbon abatement policy	 /0/;

set	quota(t)  Flag for technologies contributing to green quota;
quota(t) = no;

parameter	carblim		Carbon target,
		share		Target share for green quota,
		limit		Electricity supply limits on extant technologies;

parameter c0	Baseyear final consumption;
c0 = (-sam("y","ra")-sam("ele","ra")-sam("oil","ra") - sam("coa","ra")- sam("gas","ra"));  


parameter carbon(ff)	Base year (2001) carbon emissions by fossil fuel (in Gt) 
			/coa  2.149, gas  1.629, oil 2.584 /;

parameter	kx(t)		Extant (sector-specific) capital stock;

*	By default capital is malleable across sectors
kx(t) = 0;

*	Extension of elastic labor supply
scalar	zeta	Ratio of labor endowment to labor supply /1.75/,
	esubl	Elasticity of substitution (C for LS) /1.4/,
	tl0	Benchmark wage tax rate /0.5/,
	ld0	Base year leisure demand;

ld0 = (zeta-1) * sam("labor","ra");
